%bcond_without python3

%global modname parse_type

Name:           python-%{modname}
Version:        0.3.4
Release:        16%{?dist}
Summary:        Simplifies to build parse types based on the parse module

License:        BSD
URL:            http://pypi.python.org/pypi/parse_type
Source0:        http://pypi.python.org/packages/source/p/%{modname}/%{modname}-%{version}.tar.gz
Patch0:         parse_type-build.patch
# https://github.com/jenisys/parse_type/pull/4
Patch1:         python-parse_type-0.3.4-fix-parse-test.patch

BuildArch:      noarch

%global _description \
"parse_type" extends the "parse" module (opposite of\
"string.format()") with the following features:\
* build type converters for common use cases (enum/mapping, choice)\
* build a type converter with a cardinality constraint (0..1,\
  0..*, 1..*) from the type converter with cardinality=1.\
* compose a type converter from other type converters\
* an extended parser that supports the CardinalityField naming\
  schema and creates missing type variants (0..1, 0..*, 1..*) from\
  the primary type converter

%description %{_description}

%package -n python2-%{modname}
Summary:        %{summary}
%{?python_provide:%python_provide python2-%{modname}}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  python2-six
BuildRequires:  python2-parse >= 1.6
BuildRequires:  python2-enum34
BuildRequires:  python2-sphinx >= 1.1
Requires:       python2-six
Requires:       python2-parse
Requires:       python2-enum34

%description -n python2-%{modname} %{_description}

Python 2 version.

%if %{with python3}
%package -n python%{python3_pkgversion}-%{modname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{modname}}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-six
BuildRequires:  python%{python3_pkgversion}-parse
BuildRequires:  python%{python3_pkgversion}-sphinx >= 1.1
Requires:       python%{python3_pkgversion}-six
Requires:       python%{python3_pkgversion}-parse

%description -n python%{python3_pkgversion}-%{modname} %{_description}

Python 3 version.
%endif

%prep
%setup -q -c
mv %{modname}-%{version} python2
pushd python2
rm -vrf *.egg-info
%patch0 -p1
%patch1 -p1
popd
%if %{with python3}
cp -ai python2 python3
%endif

%build
pushd python2
  %py2_build
popd
%if %{with python3}
pushd python3
  %py3_build
popd
%endif

%install
export PYSETUP_TEST="no"
pushd python2
  %py2_install
popd
%if %{with python3}
pushd python3
  %py3_install
popd
%endif

%check
pushd python2
  %{__python2} setup.py test
popd
%if %{with python3}
pushd python3
  %{__python3} setup.py test
popd
%endif

%files -n python2-%{modname}
%license python2/LICENSE
%doc python2/README.rst
%{python2_sitelib}/%{modname}-%{version}-*.egg-info/
%{python2_sitelib}/%{modname}/
%{python2_sitelib}/_paver_ext/

%if %{with python3}
%files -n python%{python3_pkgversion}-%{modname}
%license python3/LICENSE
%doc python3/README.rst
%{python3_sitelib}/%{modname}-%{version}-*.egg-info/
%{python3_sitelib}/%{modname}/
%{python3_sitelib}/_paver_ext/
%endif

%changelog
* Mon Feb 12 2018 Iryna Shcherbina <ishcherb@redhat.com> - 0.3.4-16
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.3.4-12
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.4-11
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon May 09 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.3.4-10
- Correctly do Provides/Obsoletes

* Sun May  8 2016 Peter Robinson <pbrobinson@fedoraproject.org> 0.3.4-9
- Provide/Obsolete python-parse_type for upgrade paths

* Tue Apr 19 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.3.4-8
- Use %%license
- Use %%python_provide
- Don't use splitted dirs
- Correctly split python2- subpkg
- Other cleanups/fixes

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Dec 16 2015 Matěj Cepl <mcepl@redhat.com> - 0.3.4-6
- Whoops! Duplicated BuildRequires and Requires removed.

* Tue Dec 15 2015 Matěj Cepl <mcepl@redhat.com> - 0.3.4-5
- Remove unnecessary dependency on python-enum34 for python3 (#1286457)

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.4-4
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 19 2014 Matěj Cepl <mcepl@redhat.com> - 0.3.4-1
- initial package for Fedora
